#
# spec file for package helvum
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
%define app_id org.pipewire.Helvum
Name:           helvum
Version:        0.4.0
Release:        bp155.1.7
Summary:        A GTK patchbay for pipewire
License:        (Apache-2.0 OR BSL-1.0) AND GPL-3.0-only AND (Apache-2.0 OR MIT) AND (MIT OR Unlicense) AND Apache-2.0 AND BSD-3-Clause AND ISC AND MIT
URL:            https://gitlab.freedesktop.org/pipewire/helvum
Source:         https://gitlab.freedesktop.org/pipewire/helvum/uploads/2b68fb86bf4b988c3183de123dfd1065/%{name}-%{version}.tar.xz
BuildRequires:  cargo
BuildRequires:  clang-devel
BuildRequires:  gtk4-devel
BuildRequires:  pipewire-devel
ExcludeArch:    s390 s390x ppc ppc64 ppc64le %{ix86}

%description
Helvum is a GTK-based patchbay for pipewire, inspired by the JACK tool catia.

%prep
%setup -q

%build
RUSTFLAGS=%{rustflags} cargo build --release

%install
RUSTFLAGS=%{rustflags} cargo install --no-track --root=%{buildroot}%{_prefix} --path .
sed 's/@icon@/%{app_id}/g' data/%{app_id}.desktop.in > data/%{app_id}.desktop
install -D -m0644 -t %{buildroot}%{_datadir}/applications/ data/%{app_id}.desktop
install -D -m0644 -t %{buildroot}%{_datadir}/icons/hicolor/scalable/apps data/icons/%{app_id}.svg
install -D -m0644 -t %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps data/icons/%{app_id}-symbolic.svg

%files
%{_bindir}/helvum
%{_datadir}/applications/%{app_id}.desktop
%{_datadir}/icons/hicolor/

%changelog
* Mon Feb 13 2023 Adam Mizerski <adam@mizerski.pl>
- update to 0.4.0
  - Improvements
  - The graphview no longer renders content outside the visible area and uses
    less CPU drawing, which should improve performance greatly.
  - The graphview can now be zoomed. Zooming is possible via
    two-finger-gesture, CTRL+Scrolling, and a zoom widget in the header bar.
  - The graphview now has a fixed size, and the view is initially centered in
    middle.
  - Labels on nodes and ports now may use multiple lines when too long, and
    very long labels will be ellipsized. A new tooltip is displayed when
    hovering a label, which displays the full name and is never ellipsized.
  - The label for a node now prefers displaying the node.description property
    over the node.nick property of a pipewire node, which is usually more
    human-readable and helpful, and also matches the behaviour of other tools.
  - Fixes
  - Helvum should build again with pipewire versions 0.3.64 and 0.3.65 due to
    an updated pipewire dependency.
* Wed Feb  2 2022 Adam Mizerski <adam@mizerski.pl>
- update to 0.3.4
  - Update glib dependency, which fixes a SIGSEGV when using glib as a log
    backend and the output is being captured by systemd.
* Fri Jan 28 2022 Adam Mizerski <adam@mizerski.pl>
- update to 0.3.3
  - An appstream metadata file was added and is installed to the metainfo directory
  - gtk4-update-icon-cache instead of the gtk3 variant is used during post-install
  - The application id was changed to `org.pipewire.Helvum`
  - Bash build scripts were removed and their work is done directly via meson instead
  - The upstream URL has changed to https://gitlab.freedesktop.org/pipewire/helvum
* Mon Dec  6 2021 William Franco Abdul Hai <haiwilliam0@gmail.com>
- Fixes:
  - Changed location of hicolor folder to properly display app icon.
* Tue Nov 30 2021 Adam Mizerski <adam@mizerski.pl>
- update to 0.3.2
  - Changes:
  - Links where the endpoint is left of the start point and on the same height
    now have a slight vertical component in their curve so they don't appear
    as a single line
  - Links now use a gray instead of black color for better constrast
  - Fixes:
  - Build scripts now use bash instead of sh, as they were already using bash
    features before, which could lead to problems where sh is not a symlink to
    bash
  - Also, from now on, releases will have a source tarball with vendored cargo
    dependencies attached, so that releases can be built offline easier.
* Fri Oct  1 2021 adam@mizerski.pl
- Update to version 0.3.1:
  - Add meson as new primary buildsystem
  - Add application icon and symbolic icon
  - Add .desktop file
* Sun Aug  8 2021 adam@mizerski.pl
- Update to version 0.3.0:
  - Improvements
  - Links that are currently inactive are drawn using a dashed line
  - New nodes are positioned with some spacing to the window border
  - Links can now be created by dragging a port to another in both directions
  - Fixes
  - The build no longer fails with pipewire >= 0.3.32
* Mon Jun 14 2021 Adam Mizerski <adam@mizerski.pl>
- new package; version 0.2.1
